CommEdge

Struct CommEdge 

pub struct CommEdge {
    pub id: CommEdgeId,
    pub source: PartitionId,
    pub dest: PartitionId,
    pub weight: u64,
    pub last_epoch: u32,
}
A weighted communication edge between two partitions.

Edges are the weighted links in the coherence graph. Weight represents accumulated message bytes, decayed per epoch. The mincut algorithm identifies the cheapest set of edges to sever for partition splitting.

Fields

id: CommEdgeId

Unique identifier for this edge.

source: PartitionId

Source partition.

dest: PartitionId

Destination partition.

weight: u64

Edge weight (accumulated message bytes, decayed per epoch).

last_epoch: u32

Epoch in which this edge was last updated.